@@ -160,3 +160,15 @@ def deploycode(branch):
 def dbmigrate_docker(containerid,codepath='/data/deploy/current'):
     run('docker exec -it %s /bin/bash -c "cd /data/deploy/current && python manage.py migrate --noinput --ignore-ghost-migrations"' % containerid)
 
+@task
+def restart_nginx():
+    run("supervisorctl restart nginx")
+
+@task
+def restart_uwsgi():
+    run("supervisorctl restart uwsgi")
+
+@task
+def restart_celery():
+    run("supervisorctl restart celery")
+
